==> anwiba-spatial-data-ckan-1.1.121-sources.jar: net/anwiba/spatial/ckan/json/schema/v1_0/Organization.java <==
//Copyright (c) 2017 by Andreas W. Bartels
package net.anwiba.spatial.ckan.json.schema.v1_0;

import java.util.LinkedHashMap;
import java.util.Map;
import java.util.Objects;
import com.fasterxml.jackson.annotation.JsonAnyGetter;
import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonProperty;
import net.anwiba.spatial.ckan.json.types.DateString;

public class Organization
    extends Named
{

    private DateString created = null;
    private Boolean is_organization = Boolean.valueOf(true);
    private String state = null;
    private String image_url = null;
    private String image_display_url = null;
    private Integer package_count = Integer.valueOf(0);
    private Integer num_followers = Integer.valueOf(0);
    private String homepage = null;
    private String revision_id = null;
    private String type = null;
    private String id = null;
    private String approval_status = null;
    private final Map<java.lang.String, Object> _unknownMembers = new LinkedHashMap<java.lang.String, Object>();

    @JsonProperty("created")
    public void setCreated(final DateString created) {
        this.created = created;
    }

    @JsonProperty("created")
    public DateString getCreated() {
        return this.created;
    }

    @JsonProperty("is_organization")
    public void setIs_organization(final Boolean is_organization) {
        this.is_organization = is_organization;
    }

    @JsonProperty("is_organization")
    public Boolean is_organization() {
        return this.is_organization;
    }

    @JsonProperty("state")
    public void setState(final String state) {
        this.state = state;
    }

    @JsonProperty("state")
    public String getState() {
        return this.state;
    }

    @JsonProperty("image_url")
    public void setImage_url(final String image_url) {
        this.image_url = image_url;
    }

    @JsonProperty("image_url")
    public String getImage_url() {
        return this.image_url;
    }

    @JsonProperty("image_display_url")
    public void setImage_display_url(final String image_display_url) {
        this.image_display_url = image_display_url;
    }

    @JsonProperty("image_display_url")
    public String getImage_display_url() {
        return this.image_display_url;
    }

    @JsonProperty("package_count")
    public void setPackage_count(final Integer package_count) {
        this.package_count = package_count;
    }

    @JsonProperty("package_count")
    public Integer getPackage_count() {
        return this.package_count;
    }

    @JsonProperty("num_followers")
    public void setNum_followers(final Integer num_followers) {
        this.num_followers = num_followers;
    }

    @JsonProperty("num_followers")
    public Integer getNum_followers() {
        return this.num_followers;
    }

    @JsonProperty("homepage")
    public void setHomepage(final String homepage) {
        this.homepage = homepage;
    }

    @JsonProperty("homepage")
    public String getHomepage() {
        return this.homepage;
    }

    @JsonProperty("revision_id")
    public void setRevision_id(final String revision_id) {
        this.revision_id = revision_id;
    }

    @JsonProperty("revision_id")
    public String getRevision_id() {
        return this.revision_id;
    }

    @JsonProperty("type")
    public void setType(final String type) {
        this.type = type;
    }

    @JsonProperty("type")
    public String getType() {
        return this.type;
    }

    @JsonProperty("id")
    public void setId(final String id) {
        this.id = id;
    }

    @JsonProperty("id")
    public String getId() {
        return this.id;
    }

    @JsonProperty("approval_status")
    public void setApproval_status(final String approval_status) {
        this.approval_status = approval_status;
    }

    @JsonProperty("approval_status")
    public String getApproval_status() {
        return this.approval_status;
    }

    @JsonAnySetter
    public void set(final java.lang.String name, final Object value) {
        Objects.requireNonNull(name);
        this._unknownMembers.put(name, value);
    }

    @JsonAnyGetter
    public Map<java.lang.String, Object> get() {
        if (this._unknownMembers.isEmpty()) {
            return null;
        }
        return this._unknownMembers;
    }

}

==> anwiba-spatial-data-ckan-1.2.50-sources.jar: net/anwiba/spatial/ckan/json/schema/v1_0/Organization.java <==
//Copyright (c) 2017 by Andreas W. Bartels
package net.anwiba.spatial.ckan.json.schema.v1_0;

import java.util.LinkedHashMap;
import java.util.Map;
import java.util.Objects;
import com.fasterxml.jackson.annotation.JsonAnyGetter;
import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonProperty;
import net.anwiba.spatial.ckan.json.types.DateString;

public class Organization
    extends Named
{

    private DateString created = null;
    private Boolean is_organization = Boolean.valueOf(true);
    private String state = null;
    private String image_url = null;
    private String image_display_url = null;
    private Integer package_count = Integer.valueOf(0);
    private Integer num_followers = Integer.valueOf(0);
    private String homepage = null;
    private String revision_id = null;
    private String type = null;
    private String id = null;
    private String approval_status = null;
    private final Map<java.lang.String, Object> _unknownMembers = new LinkedHashMap<>();

    @JsonProperty("created")
    public void setCreated(final DateString created) {
        this.created = created;
    }

    @JsonProperty("created")
    public DateString getCreated() {
        return this.created;
    }

    @JsonProperty("is_organization")
    public void setIs_organization(final Boolean is_organization) {
        this.is_organization = is_organization;
    }

    @JsonProperty("is_organization")
    public Boolean is_organization() {
        return this.is_organization;
    }

    @JsonProperty("state")
    public void setState(final String state) {
        this.state = state;
    }

    @JsonProperty("state")
    public String getState() {
        return this.state;
    }

    @JsonProperty("image_url")
    public void setImage_url(final String image_url) {
        this.image_url = image_url;
    }

    @JsonProperty("image_url")
    public String getImage_url() {
        return this.image_url;
    }

    @JsonProperty("image_display_url")
    public void setImage_display_url(final String image_display_url) {
        this.image_display_url = image_display_url;
    }

    @JsonProperty("image_display_url")
    public String getImage_display_url() {
        return this.image_display_url;
    }

    @JsonProperty("package_count")
    public void setPackage_count(final Integer package_count) {
        this.package_count = package_count;
    }

    @JsonProperty("package_count")
    public Integer getPackage_count() {
        return this.package_count;
    }

    @JsonProperty("num_followers")
    public void setNum_followers(final Integer num_followers) {
        this.num_followers = num_followers;
    }

    @JsonProperty("num_followers")
    public Integer getNum_followers() {
        return this.num_followers;
    }

    @JsonProperty("homepage")
    public void setHomepage(final String homepage) {
        this.homepage = homepage;
    }

    @JsonProperty("homepage")
    public String getHomepage() {
        return this.homepage;
    }

    @JsonProperty("revision_id")
    public void setRevision_id(final String revision_id) {
        this.revision_id = revision_id;
    }

    @JsonProperty("revision_id")
    public String getRevision_id() {
        return this.revision_id;
    }

    @JsonProperty("type")
    public void setType(final String type) {
        this.type = type;
    }

    @JsonProperty("type")
    public String getType() {
        return this.type;
    }

    @JsonProperty("id")
    public void setId(final String id) {
        this.id = id;
    }

    @JsonProperty("id")
    public String getId() {
        return this.id;
    }

    @JsonProperty("approval_status")
    public void setApproval_status(final String approval_status) {
        this.approval_status = approval_status;
    }

    @JsonProperty("approval_status")
    public String getApproval_status() {
        return this.approval_status;
    }

    @JsonAnySetter
    public void set(final java.lang.String name, final Object value) {
        Objects.requireNonNull(name);
        this._unknownMembers.put(name, value);
    }

    @JsonAnyGetter
    public Map<java.lang.String, Object> get() {
        if (this._unknownMembers.isEmpty()) {
            return null;
        }
        return this._unknownMembers;
    }

}
